import { useD3 } from '../../hooks/useD3';
import React from 'react';
import * as d3 from 'd3';

function BarChart({ data }: any) {
    const ref = useD3(
    (svg: any) => {
        var margin = { top: 30, right: 30, bottom: 70, left: 60 },
        width = 460 - margin.left - margin.right,
        height = 400 - margin.top - margin.bottom;

        // X axis
        const x = d3
            .scaleBand()
            .range([0, width])
            .domain(
                data.map(function (d: any) {
                    return d.Country;
                })
            )
            .padding(0.2);

        const xAxis = (g: any) =>
            g.attr("transform", `translate(${margin.left}, ${height+10})`)
                .call(d3.axisBottom(x))
                .selectAll("text")
                .attr("transform", "translate(-10,0)rotate(-45)")
                .style("text-anchor", "end");

        // Y axis
        const y = d3.scaleLinear()
                    .domain([0, 500000])
                    .range([height, 0]);
              
        const yAxis = (g: any) =>
                    g
                      .attr("transform", `translate(${margin.left}, 10)`)
                      .style("color", "steelblue")
                      .call(d3.axisLeft(y).ticks(null, "s"))
                      .call((g: any) =>
                        g
                          .append("text")
                          .attr("x", -margin.left)
                          .attr("y", 10)
                          .attr("fill", "currentColor")
                          .attr("text-anchor", "start")
                          .text(data.y1)    
        );

        // Data
        svg.select(".x-axis").call(xAxis);
        svg.select(".y-axis").call(yAxis);

        svg.select(".plot-area")
            .attr("fill", "steelblue")
            .selectAll(".bar")
            .data(data)
            .join("rect")
            .attr("class", "bar")
            .attr("x", (d: any) => x(d.Country) + margin.left)
            .attr("width", x.bandwidth())
            .attr("y", (d: any) => y(d.Value))
            .attr("height", (d: any) => height - y(d.Value) + 10);
    },
    [data.length]
  );

  return (
    <svg
      ref={ref}
      style={{
        height: 600,
        width: "100%",
        marginTop: "20px",
        marginRight: "0px",
        marginLeft: "50px",
      }}
    >
      <g className="plot-area" />
      <g className="x-axis" />
      <g className="y-axis" />
    </svg>
  );
}

export default BarChart;
